==> nextcloud-14.0.13.zip: nextcloud/apps/federatedfilesharing/l10n/da.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Datafællesskabsdeling",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ønsker du at tilføje det eksterne drev  {name} fra {owner}@{remote}?",
    "Remote share" : "Eksterne drev",
    "Remote share password" : "Fjerndrev adgangskode",
    "Cancel" : "Annuller",
    "Add remote share" : "Tilføj ekstern deling",
    "Copy" : "Kopiér",
    "Copied!" : "Kopieret!",
    "Not supported!" : "Ikke understøttet!",
    "Press ⌘-C to copy." : "Tryk ⌘-C for kopiering.",
    "Press Ctrl-C to copy." : "Tryk Ctrl-C for at kopiere.",
    "Invalid Federated Cloud ID" : "Ugyldigt Federated Cloud ID",
    "Server to server sharing is not enabled on this server" : "Server til serverdeling er ikke slået til på denne server",
    "Couldn't establish a federated share." : "Kunne ikke skabe forbindelse til føderal deling ",
    "Couldn't establish a federated share, maybe the password was wrong." : "Kunne ikke skabe forbindelse til føderal deling, måske var passwordet forkert.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Føderal deling anmodning sendt, du vil modtage en invitation. Tjek dine notifikationer.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Kunne ikke skabe forbindelse til føderal deling, det ser ud til at føderal serveren er for gammel (Nextcloud <=9).",
    "Not allowed to create a federated share with the same user" : "Det er ikke tilladt at danne et datafællesskab med samme bruger",
    "File is already shared with %s" : "Filen deles allerede med %s",
    "Could not find share" : "Kan ikke finde deling",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Du modtog \"/%3$s\" som en ekstern deling fra %1$s (på vegne af %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Du modtog {share} som en ekstern deling fra {user} (på vegne af {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Du modtog \"%3$s\" som en ekstern deling fra %1$s",
    "You received {share} as a remote share from {user}" : "Du modtog {share} som en ekstern deling fra {user}",
    "Accept" : "Acceptér",
    "Decline" : "Afvis",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Del med mig gennem min #Nextcloud Federated Cloud ID, se %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Del med mig gennem min #Nextcloud Federated Cloud ID",
    "Sharing" : "Deling",
    "Federated Cloud Sharing" : "Sammensluttet Cloud deling",
    "Open documentation" : "Åbn dokumentation",
    "Adjust how people can share between servers." : "Juster hvordan folk kan dele mellem servere.",
    "Allow users on this server to send shares to other servers" : "Tillad brugere på denne server, at sende delinger til andre servere",
    "Allow users on this server to receive shares from other servers" : "Tillad brugere på denne server, at modtage delinger fra andre servere",
    "Search global and public address book for users" : "Søg global og offentlig adresse bog for brugere",
    "Allow users to publish their data to a global and public address book" : "Tillad brugere at offentliggøre deres data til en global adressebog ",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Din Federated Cloud ID:",
    "Share it so your friends can share files with you:" : "Del så dine venner kan dele filer med dig:",
    "Add to your website" : "Tilføj til dit websted",
    "Share with me via Nextcloud" : "Del med mig gennem Nextcloud",
    "HTML Code:" : "HTMLkode:",
    "Sharing %s failed, because this item is already shared with %s" : "Der skete en fejl ved deling af %s, objektet er allerede delt med %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Deling af %s mislykkedes - kunne ikke finde %s. Måske er serveren ikke tilgængelig i øjeblikket eller bruger et selv underskrevet certifikat."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.3.zip: nextcloud/apps/federatedfilesharing/l10n/da.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Datafællesskabsdeling",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ønsker du at tilføje det eksterne drev  {name} fra {owner}@{remote}?",
    "Remote share" : "Eksterne drev",
    "Remote share password" : "Fjerndrev adgangskode",
    "Cancel" : "Annuller",
    "Add remote share" : "Tilføj ekstern deling",
    "Copy" : "Kopiér",
    "Copied!" : "Kopieret!",
    "Not supported!" : "Ikke understøttet!",
    "Press ⌘-C to copy." : "Tryk ⌘-C for kopiering.",
    "Press Ctrl-C to copy." : "Tryk Ctrl-C for at kopiere.",
    "Invalid Federated Cloud ID" : "Ugyldigt Federated Cloud ID",
    "Server to server sharing is not enabled on this server" : "Server til serverdeling er ikke slået til på denne server",
    "Couldn't establish a federated share." : "Kunne ikke skabe forbindelse til føderal deling ",
    "Couldn't establish a federated share, maybe the password was wrong." : "Kunne ikke skabe forbindelse til føderal deling, måske var passwordet forkert.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Føderal deling anmodning sendt, du vil modtage en invitation. Tjek dine notifikationer.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Kunne ikke skabe forbindelse til føderal deling, det ser ud til at føderal serveren er for gammel (Nextcloud <=9).",
    "Not allowed to create a federated share with the same user" : "Det er ikke tilladt at danne et datafællesskab med samme bruger",
    "File is already shared with %s" : "Filen deles allerede med %s",
    "Could not find share" : "Kan ikke finde deling",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Du modtog \"/%3$s\" som en ekstern deling fra %1$s (på vegne af %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Du modtog {share} som en ekstern deling fra {user} (på vegne af {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Du modtog \"%3$s\" som en ekstern deling fra %1$s",
    "You received {share} as a remote share from {user}" : "Du modtog {share} som en ekstern deling fra {user}",
    "Accept" : "Acceptér",
    "Decline" : "Afvis",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Del med mig gennem min #Nextcloud Federated Cloud ID, se %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Del med mig gennem min #Nextcloud Federated Cloud ID",
    "Sharing" : "Deling",
    "Federated Cloud Sharing" : "Sammensluttet Cloud deling",
    "Open documentation" : "Åben dokumentation",
    "Adjust how people can share between servers." : "Juster hvordan folk kan dele mellem servere.",
    "Allow users on this server to send shares to other servers" : "Tillad brugere på denne server, at sende delinger til andre servere",
    "Allow users on this server to receive shares from other servers" : "Tillad brugere på denne server, at modtage delinger fra andre servere",
    "Search global and public address book for users" : "Søg global og offentlig adresse bog for brugere",
    "Allow users to publish their data to a global and public address book" : "Tillad brugere at offentliggøre deres data til en global adressebog ",
    "Federated Cloud" : "Federated Cloud",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Du kan dele med hvem som helst som bruger Nextcloud, ownCloud eller Pydio! Bare put deres Federated Cloud ID i delingsdialogen. Det ser sådan her ud person@cloud.example.com",
    "Your Federated Cloud ID:" : "Din Federated Cloud ID:",
    "Share it so your friends can share files with you:" : "Del så dine venner kan dele filer med dig:",
    "Add to your website" : "Tilføj til dit websted",
    "Share with me via Nextcloud" : "Del med mig gennem Nextcloud",
    "HTML Code:" : "HTMLkode:",
    "The mountpoint name contains invalid characters." : "Monteringspunktets navn indeholder ugyldige tegn.",
    "Not allowed to create a federated share with the owner." : "Det er ikke tilladt at danne et datafællesskab med ejeren.",
    "Invalid or untrusted SSL certificate" : "Ugyldigt eller upålideligt SSL-certifikat",
    "Could not authenticate to remote share, password might be wrong" : "Kunne ikke godkende fjerndelingen - kodeordet er muilgvis forkert",
    "Storage not valid" : "Lagerplads er ikke gyldig",
    "Federated share added" : "Datafællesskabsdeling tilføjet",
    "Couldn't add remote share" : "Kunne ikke tliføje den ekstern deling",
    "Sharing %s failed, because this item is already shared with %s" : "Der skete en fejl ved deling af %s, objektet er allerede delt med %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Deling af %s mislykkedes - kunne ikke finde %s. Måske er serveren ikke tilgængelig i øjeblikket eller bruger et selv underskrevet certifikat."
},
"nplurals=2; plural=(n != 1);");
